integer

Function integer 

pub fn integer(
    text: &str,
    std: Std,
    target: &TargetInfo,
) -> Result<IntConstant, IntError>
Converts the spelling of a preprocessing number into an integer constant.

Errors

IntError, one case of which is that the spelling is a floating constant rather than a malformed integer one.