string

Function string 

pub fn string(
    text: &str,
    std: Std,
    target: &TargetInfo,
) -> Result<StringLiteral, LiteralError>
Converts the spelling of a string literal into its elements.

Errors

LiteralError, for a spelling that is not a string literal or that holds an escape that is not one.