Tokens

Struct Tokens 

pub struct Tokens {
    pub tokens: Vec<Token>,
    pub ints: Vec<IntConstant>,
    pub floats: Vec<FloatConstant>,
    pub chars: Vec<CharConstant>,
    pub strings: Vec<StringLiteral>,
    pub pragmas: Vec<Pragma>,
}
The tokens of a translation unit, with the values they refer to.

Fields

tokens: Vec<Token>

The tokens themselves, ending in one TokenKind::Eof.

ints: Vec<IntConstant>

The integer constants, in the order they were converted.

floats: Vec<FloatConstant>

The floating constants, in the order they were converted.

chars: Vec<CharConstant>

The character constants, in the order they were converted.

strings: Vec<StringLiteral>

The string literals, one per run of adjacent ones.

pragmas: Vec<Pragma>

The #pragma lines, in the order they were written.

Implementations

Source

impl Tokens

pub fn int(&self, token: Token) -> Option<&IntConstant>

The integer constant token refers to, and None when it is not an integer constant.

pub fn float(&self, token: Token) -> Option<&FloatConstant>

The floating constant token refers to, and None when it is not one.

pub fn character(&self, token: Token) -> Option<&CharConstant>

The character constant token refers to, and None when it is not one.

pub fn string(&self, token: Token) -> Option<&StringLiteral>

The string literal token refers to, and None when it is not one.