pub fn floating(
text: &str,
std: Std,
target: &TargetInfo,
) -> Result<FloatConstant, FloatError>Expand description
Converts the spelling of a preprocessing number into a floating constant.
Errors
FloatError, one case of which is that the spelling is an integer constant rather than a
malformed floating one.